@@ -881,7 +881,44 @@ load_rownames_dataset_attribute (SEXP call, hid_t dataset, SEXP vec)
   H5Eset_auto (errfunc, client_data);
 
   if (rnattrib < 0)
-    return;
+    {
+      hid_t space;
+      unsigned rank;
+
+      if ((space = H5Dget_space (dataset)) < 0)
+	errorcall (call, "unable to get dataset space");
+
+      if (H5Sis_simple (space) != LTRUE)
+	errorcall (call, "space not simple");
+
+      if ((rank = H5Sget_simple_extent_ndims (space)) < 0)
+	errorcall (call, "unable to get space rank");
+
+      if (rank != 1)
+        errorcall (call, "rank not 1");
+
+      {
+	hsize_t dims[rank];
+	hsize_t maxdims[rank];
+        unsigned i;
+        char buf[20];
+
+	if (H5Sget_simple_extent_dims (space, dims, maxdims) < 0)
+	  errorcall (call, "unable to get space extent");
+
+        rowcount = dims[0];
+        PROTECT (rownames = allocVector (STRSXP, rowcount));
+
+        for (i = 0; i < rowcount; i++)
+          {
+            sprintf (buf, "%u", i);
+            STRING (rownames)[i] = mkChar (buf);
+          }
+      }      
+      setAttrib (vec, R_RowNamesSymbol, rownames);
+      UNPROTECT (1);
+      return;
+    }
 
   if ((rnspace = H5Aget_space (rnattrib)) < 0)
     errorcall (call, "could not get space for rownames attribute");
